package controllers

import (
	"encoding/json"
	"eta/eta_report/models"
	"eta/eta_report/services"
	"eta/eta_report/utils"
	"github.com/beego/beego/v2/server/web"
	"net/http"
	"net/url"
)

type BaseCommonController struct {
	web.Controller
	Token string
}

func (this *BaseCommonController) Prepare() {

}

func (c *BaseCommonController) ServeJSON(encoding ...bool) {
	var (
		hasIndent   = false
		hasEncoding = false
	)
	if web.BConfig.RunMode == web.PROD {
		hasIndent = false
	}
	if len(encoding) > 0 && encoding[0] == true {
		hasEncoding = true
	}
	if c.Data["json"] == nil {
		go utils.SendEmail(utils.APPNAME+" "+utils.RunMode+"异常提醒", "接口:"+"URI:"+c.Ctx.Input.URI()+";无返回值", utils.EmailSendToUsers)
		return
	}
	baseRes := c.Data["json"].(*models.BaseResponse)
	if baseRes != nil && !baseRes.Success && baseRes.IsSendEmail {
		go utils.SendEmail(utils.APPNAME+" "+utils.RunMode+" 失败提醒", "URI:"+c.Ctx.Input.URI()+" ErrMsg:"+baseRes.ErrMsg+";Msg"+baseRes.Msg, utils.EmailSendToUsers)
	}
	c.JSON(c.Data["json"], hasIndent, hasEncoding)
}

func (c *BaseCommonController) JSON(data interface{}, hasIndent bool, coding bool) error {
	c.Ctx.Output.Header("Content-Type", "application/json; charset=utf-8")
	var content []byte
	var err error
	if hasIndent {
		content, err = json.MarshalIndent(data, "", "  ")
	} else {
		content, err = json.Marshal(data)
	}
	if err != nil {
		http.Error(c.Ctx.Output.Context.ResponseWriter, err.Error(), http.StatusInternalServerError)
		return err
	}
	ip := c.Ctx.Input.IP()
	requestBody, err := url.QueryUnescape(string(c.Ctx.Input.RequestBody))
	if err != nil {
		requestBody = string(c.Ctx.Input.RequestBody)
	}
	if requestBody == "" {
		requestBody = c.Ctx.Input.URI()
	}
	c.logUri(content, requestBody, ip)
	if coding {
		content = []byte(utils.StringsToJSON(string(content)))
	}

	// 数据加密
	if services.CheckEncryption() {
		content = utils.DesBase64Encrypt(content)
		// get请求时，不加双引号就获取不到数据，不知道什么原因，所以还是在前后加上双引号吧
		content = []byte(`"` + string(content) + `"`)
	}

	return c.Ctx.Output.Body(content)
}

func (c *BaseCommonController) logUri(content []byte, requestBody, ip string) {
	utils.ApiLog.Info("uri:%s, requestBody:%s, responseBody:%s, ip:%s", c.Ctx.Input.URI(), requestBody, content, ip)
	return
}
